@@ -1,4 +1,4 @@
-/* -*- mode: C; c-file-style: "gnu" -*- */
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /* dbus-transport.c DBusTransport object (internal to D-Bus implementation)
  *
  * Copyright (C) 2002, 2003  Red Hat Inc.
@@ -354,8 +354,8 @@ _dbus_transport_open (DBusAddressEntry *entry,
   const char *expected_guid_orig;
   char *expected_guid;
   int i;
-  DBusError tmp_error;
-  
+  DBusError tmp_error = DBUS_ERROR_INIT;
+
   _DBUS_ASSERT_ERROR_IS_CLEAR (error);
   
   transport = NULL;
@@ -368,7 +368,6 @@ _dbus_transport_open (DBusAddressEntry *entry,
       return NULL;
     }
 
-  dbus_error_init (&tmp_error);
   for (i = 0; i < (int) _DBUS_N_ELEMENTS (open_funcs); ++i)
     {
       DBusTransportOpenResult result;
@@ -619,21 +618,31 @@ auth_via_default_rules (DBusTransport *transport)
       _dbus_credentials_same_user (our_identity,
                                    auth_identity))
     {
-      /* FIXME the verbose spam here is unix-specific */                  
-      _dbus_verbose ("Client authorized as UID "DBUS_UID_FORMAT
-                     " matching our UID "DBUS_UID_FORMAT"\n",
-                     _dbus_credentials_get_unix_uid(auth_identity),
-                     _dbus_credentials_get_unix_uid(our_identity));
+      if (_dbus_credentials_include(our_identity,DBUS_CREDENTIAL_WINDOWS_SID))
+          _dbus_verbose ("Client authorized as SID '%s'"
+                         "matching our SID '%s'\n",
+                         _dbus_credentials_get_windows_sid(auth_identity),
+                         _dbus_credentials_get_windows_sid(our_identity));
+      else
+          _dbus_verbose ("Client authorized as UID "DBUS_UID_FORMAT
+                         " matching our UID "DBUS_UID_FORMAT"\n",
+                         _dbus_credentials_get_unix_uid(auth_identity),
+                         _dbus_credentials_get_unix_uid(our_identity));
       /* We have authenticated! */
       allow = TRUE;
     }
   else
     {
-      /* FIXME the verbose spam here is unix-specific */
-      _dbus_verbose ("Client authorized as UID "DBUS_UID_FORMAT
-                     " but our UID is "DBUS_UID_FORMAT", disconnecting\n",
-                     _dbus_credentials_get_unix_uid(our_identity),
-                     _dbus_credentials_get_unix_uid(our_identity));
+      if (_dbus_credentials_include(our_identity,DBUS_CREDENTIAL_WINDOWS_SID))
+          _dbus_verbose ("Client authorized as SID '%s'"
+                         " but our SID is '%s', disconnecting\n",
+                         _dbus_credentials_get_windows_sid(our_identity),
+                         _dbus_credentials_get_windows_sid(our_identity));
+      else
+          _dbus_verbose ("Client authorized as UID "DBUS_UID_FORMAT
+                         " but our UID is "DBUS_UID_FORMAT", disconnecting\n",
+                         _dbus_credentials_get_unix_uid(our_identity),
+                         _dbus_credentials_get_unix_uid(our_identity));
       _dbus_transport_disconnect (transport);
       allow = FALSE;
     }  
